# OSBot-AWS
Large number of AWS apis and utils from the OWASP Security Bot (OSBot) which make
the use of AWS's boto3 library easier and more intuitive.

### Install

Current stable release is v1.0.0 and is available here 

https://github.com/owasp-sbot/OSBot-AWS/releases/tag/v1.0.0

## curent dev version is 2.x.x 

This version has a number of breaking changes, mainly on the location of the apis, 
since we are moving into a spefici folder per service (e.g. S3, SQS, etc)

### Install from PyPi

There is a version in PyPi (which is not the latest version)

`pip3 install osbot-aws`

https://pypi.org/project/osbot-aws/
